@@ -1,23 +1,26 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
 Photutils is an Astropy affiliated package to provide tools for
-detecting and performing photometry of astronomical sources.  It also
-has tools for background estimation, ePSF building, PSF matching,
-centroiding, and morphological measurements.
+detecting and performing photometry of astronomical sources. It also has
+tools for background estimation, ePSF building, PSF matching, radial
+profiles, centroiding, and morphological measurements.
+
 """
 
 import warnings
 
-# Affiliated packages may add whatever they like to this file, but
-# should keep this content at the top.
-from ._astropy_init import *  # noqa: F401, F403
-
 from . import aperture
 from . import background
 from . import detection
 from . import psf
 from . import segmentation
 
+try:
+    from .version import version as __version__
+except ImportError:
+    __version__ = ''
+
+
 # deprecations
 __depr__ = {}
 
@@ -44,14 +47,9 @@ __depr__[detection] = ('StarFinderBase', 'DAOStarFinder', 'IRAFStarFinder',
                        'find_peaks', 'StarFinder')
 
 __depr__[psf] = ('EPSFFitter', 'EPSFBuilder', 'EPSFStar', 'EPSFStars',
-                 'LinkedEPSFStar', 'extract_stars', 'DAOGroup', 'DBSCANGroup',
-                 'GroupStarsBase', 'NonNormalizable', 'FittableImageModel',
+                 'LinkedEPSFStar', 'extract_stars', 'FittableImageModel',
                  'EPSFModel', 'GriddedPSFModel', 'IntegratedGaussianPRF',
-                 'PRFAdapter', 'BasicPSFPhotometry',
-                 'IterativelySubtractedPSFPhotometry', 'DAOPhotPSFPhotometry',
-                 'prepare_psf_model',
-                 'get_grouped_psf_model', 'subtract_psf',
-                 'resize_psf', 'create_matching_kernel',
+                 'PRFAdapter', 'resize_psf', 'create_matching_kernel',
                  'SplitCosineBellWindow', 'HanningWindow', 'TukeyWindow',
                  'CosineBellWindow', 'TopHatWindow')
 
