@@ -34,15 +34,15 @@ class EllipticalMaskMixin:
         Parameters
         ----------
         method : {'exact', 'center', 'subpixel'}, optional
-            The method used to determine the overlap of the aperture on
-            the pixel grid.  Not all options are available for all
-            aperture types.  Note that the more precise methods are
-            generally slower.  The following methods are available:
+            The method used to determine the overlap of the aperture
+            on the pixel grid. Not all options are available for all
+            aperture types. Note that the more precise methods are
+            generally slower. The following methods are available:
 
                 * ``'exact'`` (default):
-                  The the exact fractional overlap of the aperture and
-                  each pixel is calculated. The aperture weights will
-                  contain values between 0 and 1.
+                  The exact fractional overlap of the aperture and each
+                  pixel is calculated. The aperture weights will contain
+                  values between 0 and 1.
 
                 * ``'center'``:
                   A pixel is considered to be entirely in or out of the
@@ -68,8 +68,8 @@ class EllipticalMaskMixin:
         Returns
         -------
         mask : `~photutils.aperture.ApertureMask` or list of `~photutils.aperture.ApertureMask`
-            A mask for the aperture.  If the aperture is scalar then a
-            single `~photutils.aperture.ApertureMask` is returned,
+            A mask for the aperture. If the aperture is scalar then
+            a single `~photutils.aperture.ApertureMask` is returned,
             otherwise a list of `~photutils.aperture.ApertureMask` is
             returned.
         """
@@ -212,7 +212,7 @@ class EllipticalAperture(EllipticalMaskMixin, PixelAperture):
         Returns
         -------
         patch : `~matplotlib.patches.patch` or list of `~matplotlib.patches.patch`
-            A patch for the aperture.  If the aperture is scalar then a
+            A patch for the aperture. If the aperture is scalar then a
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
@@ -285,7 +285,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
 
     b_in : `None` or float, optional
         The inner semiminor axis of the elliptical annulus in pixels.
-        If `None`, then the the inner semiminor axis is calculated as:
+        If `None`, then the inner semiminor axis is calculated as:
 
             .. math:: b_{in} = b_{out}
                 \left(\frac{a_{in}}{a_{out}}\right)
@@ -377,7 +377,7 @@ class EllipticalAnnulus(EllipticalMaskMixin, PixelAperture):
         Returns
         -------
         patch : `~matplotlib.patches.patch` or list of `~matplotlib.patches.patch`
-            A patch for the aperture.  If the aperture is scalar then a
+            A patch for the aperture. If the aperture is scalar then a
             single `~matplotlib.patches.patch` is returned, otherwise a
             list of `~matplotlib.patches.patch` is returned.
         """
@@ -447,7 +447,7 @@ class SkyEllipticalAperture(SkyAperture):
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the ellipse semimajor
-        axis.  For a right-handed world coordinate system, the position
+        axis. For a right-handed world coordinate system, the position
         angle increases counterclockwise from North (PA=0).
 
     Examples
@@ -524,7 +524,7 @@ class SkyEllipticalAnnulus(SkyAperture):
 
     theta : scalar `~astropy.units.Quantity`, optional
         The position angle (in angular units) of the ellipse semimajor
-        axis.  For a right-handed world coordinate system, the position
+        axis. For a right-handed world coordinate system, the position
         angle increases counterclockwise from North (PA=0).
 
     Examples
