@@ -7,9 +7,12 @@ import warnings
 
 import astropy.units as u
 import numpy as np
+from astropy.utils import minversion
 
 __all__ = ['ApertureMask']
 
+COPY_IF_NEEDED = False if not minversion(np, '2.0.0.dev') else None
+
 
 class ApertureMask:
     """
@@ -36,12 +39,12 @@ class ApertureMask:
         self.bbox = bbox
         self._mask = (self.data == 0)
 
-    def __array__(self, dtype=None):
+    def __array__(self, dtype=None, copy=COPY_IF_NEEDED):
         """
         Array representation of the mask data array (e.g., for
         matplotlib).
         """
-        return np.asarray(self.data, dtype=dtype)
+        return np.array(self.data, dtype=dtype, copy=copy)
 
     @property
     def shape(self):
@@ -127,27 +130,26 @@ class ApertureMask:
 
         fill_value : float, optional
             The value used to fill pixels where the aperture mask does
-            not overlap with the input ``data``.  The default is 0.
+            not overlap with the input ``data``. The default is 0.
 
         copy : bool, optional
             If `True` then the returned cutout array will always be hold
-            a copy of the input ``data``.  If `False` and the mask is
+            a copy of the input ``data``. If `False` and the mask is
             fully within the input ``data``, then the returned cutout
-            array will be a view into the input ``data``.  In cases
-            where the mask partially overlaps or has no overlap with the
-            input ``data``, the returned cutout array will always hold a
-            copy of the input ``data`` (i.e., this keyword has no
-            effect).
+            array will be a view into the input ``data``. In cases where
+            the mask partially overlaps or has no overlap with the input
+            ``data``, the returned cutout array will always hold a copy
+            of the input ``data`` (i.e., this keyword has no effect).
 
         Returns
         -------
         result : `~numpy.ndarray` or `None`
-            A 2D array cut out from the input ``data`` representing the
-            same cutout region as the aperture mask.  If there is a
-            partial overlap of the aperture mask with the input data,
-            pixels outside of the data will be assigned to
-            ``fill_value``.  `None` is returned if there is no overlap
-            of the aperture with the input ``data``.
+            A 2D array cut out from the input ``data`` representing
+            the same cutout region as the aperture mask. If there is
+            a partial overlap of the aperture mask with the input
+            data, pixels outside of the data will be assigned to
+            ``fill_value``. `None` is returned if there is no overlap of
+            the aperture with the input ``data``.
         """
         data = np.asanyarray(data)
         if data.ndim != 2:
@@ -196,7 +198,7 @@ class ApertureMask:
 
         fill_value : float, optional
             The value is used to fill pixels where the aperture mask
-            does not overlap with the input ``data``.  The default is 0.
+            does not overlap with the input ``data``. The default is 0.
 
         Returns
         -------
