@@ -119,9 +119,9 @@ class ApertureStats:
         all aperture types. The following methods are available:
 
           * ``'exact'`` (default):
-            The the exact fractional overlap of the aperture and each
-            pixel is calculated. The aperture weights will contain
-            values between 0 and 1.
+            The exact fractional overlap of the aperture and each pixel
+            is calculated. The aperture weights will contain values
+            between 0 and 1.
 
           * ``'center'``:
             A pixel is considered to be entirely in or out of the
@@ -144,15 +144,15 @@ class ApertureStats:
         ``sum_method='subpixel'``.
 
     local_bkg : float, `~numpy.ndarray`,  `~astropy.units.Quantity`, or `None`
-        The *per-pixel* local background values to subtract from the
-        data before performing measurements. If input as any array,
-        the order of ``local_bkg`` values corresponds to the order
-        of the input ``aperture`` positions. ``local_bkg`` must have
-        the same length as the the input ``aperture`` or must be a
-        scalar value, which will be broadcast to all apertures. If
-        `None`, then no local background subtraction is performed. If
-        the input ``data`` has units, then ``local_bkg`` must be a
-        `~astropy.units.Quantity` with the same units.
+        The per-pixel local background values to subtract from the data
+        before performing measurements. If input as an array, the order
+        of ``local_bkg`` values corresponds to the order of the input
+        ``aperture`` positions. ``local_bkg`` must have the same length
+        as the input ``aperture`` or must be a scalar value, which
+        will be broadcast to all apertures. If `None`, then no local
+        background subtraction is performed. If the input ``data`` has
+        units, then ``local_bkg`` must be a `~astropy.units.Quantity`
+        with the same units.
 
     Notes
     -----
@@ -184,17 +184,17 @@ class ApertureStats:
     >>> aper = CircularAperture((150, 25), 8)
     >>> aperstats = ApertureStats(data, aper)
     >>> print(aperstats.xcentroid)  # doctest: +FLOAT_CMP
-    149.98737072209013
+    149.99080259251238
     >>> print(aperstats.ycentroid)  # doctest: +FLOAT_CMP
-    24.99729176183652
+    24.97484633000507
     >>> print(aperstats.centroid)  # doctest: +FLOAT_CMP
-    [149.98737072  24.99729176]
+    [149.99080259  24.97484633]
 
     >>> print(aperstats.mean, aperstats.median, aperstats.std) #  doctest: +FLOAT_CMP
-    46.861845146453526 33.743501730319 38.25291812758177
+    47.76300955780609 31.913789514433084 39.193655383492974
 
     >>> print(aperstats.sum)  # doctest: +FLOAT_CMP
-    9118.129697119366
+    9286.709206410273
 
     >>> print(aperstats.sum_aper_area) # doctest: +FLOAT_CMP
     201.0619298297468 pix2
@@ -203,9 +203,9 @@ class ApertureStats:
     >>> aper2 = CircularAperture(((150, 25), (90, 60)), 10)
     >>> aperstats2 = ApertureStats(data, aper2)
     >>> print(aperstats2.xcentroid)  # doctest: +FLOAT_CMP
-    [149.97230436  90.00833613]
+    [149.98470724  89.97893946]
     >>> print(aperstats2.sum)  # doctest: +FLOAT_CMP
-    [ 9863.56195844 36629.52906175]
+    [10177.62548482 36653.97704059]
     """
 
     def __init__(self, data, aperture, *, error=None, mask=None, wcs=None,
@@ -216,8 +216,11 @@ class ApertureStats:
             data, error, mask, wcs = self._unpack_nddata(data, error, mask,
                                                          wcs)
 
-        (data, error, local_bkg), unit = process_quantities(
-            (data, error, local_bkg), ('data', 'error', 'local_bkg'))
+        inputs = (data, error, local_bkg)
+        names = ('data', 'error', 'local_bkg')
+        inputs, unit = process_quantities(inputs, names)
+        (data, error, local_bkg) = inputs
+
         self._data = self._validate_array(data, 'data', shape=False)
         self._data_unit = unit
         self.aperture = self._validate_aperture(aperture)
@@ -1394,8 +1397,13 @@ class ApertureStats:
         with warnings.catch_warnings():
             warnings.simplefilter('ignore', RuntimeWarning)
             covar_det = np.linalg.det(covar)
+
+            # covariance should be positive semidefinite
+            idx = np.where(covar_det < 0)[0]
+            covar[idx] = np.array([[np.nan, np.nan], [np.nan, np.nan]])
+
             idx = np.where(covar_det < delta2)[0]
-            while idx.size > 0:  # pragma: no cover
+            while idx.size > 0:
                 covar[idx, 0, 0] += delta
                 covar[idx, 1, 1] += delta
                 covar_det = np.linalg.det(covar)
@@ -1425,7 +1433,7 @@ class ApertureStats:
         eigvals[idx] = np.linalg.eigvals(self._covariance[idx])
 
         # check for negative variance
-        # (just in case covariance matrix is not positive (semi)definite)
+        # (just in case covariance matrix is not positive semidefinite)
         idx2 = np.unique(np.where(eigvals < 0)[0])  # pragma: no cover
         eigvals[idx2] = (np.nan, np.nan)  # pragma: no cover
 
