@@ -23,7 +23,7 @@ from photutils.utils._stats import nanmedian
 
 __all__ = ['Background2D']
 
-__doctest_requires__ = {('Background2D'): ['scipy']}
+__doctest_requires__ = {'Background2D': ['scipy']}
 
 
 class Background2D:
@@ -270,15 +270,20 @@ class Background2D:
 
         This method:
           * converts the data to float dtype (and makes a copy)
-          * automatically masks non-finite values
+          * automatically masks non-finite values that aren't already masked
           * replaces all masked values with NaN
           * converts MaskedArray to ndarray using NaN as masked values
         """
         # float array type is needed to insert nans into the array
         self.data = self.data.astype(float)  # makes a copy
 
-        # include non-finite values in the total mask
-        bad_mask = ~np.isfinite(self.data)
+        # add non-finite values not already masked to the total mask
+        bad_mask = np.isfinite(self.data)
+
+        if self.total_mask is not None:
+            bad_mask |= self.total_mask
+        bad_mask = np.invert(bad_mask, out=bad_mask)
+
         if np.any(bad_mask):
             if self.total_mask is None:
                 self.total_mask = bad_mask
@@ -458,7 +463,7 @@ class Background2D:
 
         power : float, optional
             The power of the inverse distance used for the interpolation
-            weights.  See the Notes section for more details.
+            weights. See the Notes section for more details.
 
         reg : float, optional
             The regularization parameter. It may be used to control the
@@ -676,7 +681,7 @@ class Background2D:
         Parameters
         ----------
         ax : `matplotlib.axes.Axes` or `None`, optional
-            The matplotlib axes on which to plot.  If `None`, then the
+            The matplotlib axes on which to plot. If `None`, then the
             current `~matplotlib.axes.Axes` instance is used.
 
         marker : str, optional
