@@ -15,6 +15,7 @@ from numpy.testing import assert_allclose
 from photutils.centroids.core import (centroid_com, centroid_quadratic,
                                       centroid_sources)
 from photutils.centroids.gaussian import centroid_1dg, centroid_2dg
+from photutils.datasets import make_4gaussians_image, make_noise_image
 from photutils.utils._optional_deps import HAS_SCIPY
 
 XCEN = 25.7
@@ -36,7 +37,7 @@ CENTROID_FUNCS = (centroid_com, centroid_quadratic, centroid_1dg,
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize(('x_std', 'y_std', 'theta'),
                          list(itertools.product(XSTDS, YSTDS, THETAS)))
-def test_centroid_com(x_std, y_std, theta):
+def test_centroid_comquad(x_std, y_std, theta):
     model = Gaussian2D(2.4, XCEN, YCEN, x_stddev=x_std, y_stddev=y_std,
                        theta=theta)
     y, x = np.mgrid[0:50, 0:47]
@@ -60,7 +61,7 @@ def test_centroid_com(x_std, y_std, theta):
 
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize('use_mask', [True, False])
-def test_centroid_com_nan_withmask(use_mask):
+def test_centroid_comquad_nan_withmask(use_mask):
     xc_ref = 24.7
     yc_ref = 25.2
     model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=5.0, y_stddev=5.0)
@@ -85,15 +86,30 @@ def test_centroid_com_nan_withmask(use_mask):
         if nwarn == 1:
             assert len(warnlist) == nwarn
 
-    ctx = pytest.warns(AstropyUserWarning,
-                       match='Input data contains non-finite values')
     with ctx as warnlist:
         xc, yc = centroid_quadratic(data, mask=mask)
         assert_allclose(xc, xc_ref, rtol=0, atol=0.15)
-        assert len(warnlist) == 1
+        if nwarn == 1:
+            assert len(warnlist) == nwarn
+
+
+def test_centroid_com_allmask():
+    xc_ref = 24.7
+    yc_ref = 25.2
+    model = Gaussian2D(2.4, xc_ref, yc_ref, x_stddev=5.0, y_stddev=5.0)
+    y, x = np.mgrid[0:50, 0:50]
+    data = model(x, y)
+    mask = np.ones(data.shape, dtype=bool)
+    xc, yc = centroid_com(data, mask=mask)
+    assert np.isnan(xc)
+    assert np.isnan(yc)
+
+    data = np.zeros((25, 25))
+    xc, yc = centroid_com(data, mask=None)
+    assert np.isnan(xc)
+    assert np.isnan(yc)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_com_invalid_inputs():
     data = np.zeros((4, 4))
     mask = np.zeros((2, 2), dtype=bool)
@@ -126,6 +142,20 @@ def test_centroid_quadratic_xypeak():
         centroid_quadratic(data, xpeak=15, ypeak=15)
 
 
+@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_centroid_quadratic_nan():
+    gmodel = Gaussian2D(42.1, 47.8, 52.4, 4.7, 4.7, 0)
+    yy, xx = np.mgrid[0:100, 0:100]
+    data = gmodel(xx, yy)
+    error = make_noise_image(data.shape, mean=0., stddev=2.4, seed=123)
+    data += error
+
+    data[50, 50] = np.nan
+    mask = ~np.isfinite(data)
+    xycen = centroid_quadratic(data, xpeak=47, ypeak=52, mask=mask)
+    assert_allclose(xycen, [47.58324, 51.827182])
+
+
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_npts():
     data = np.zeros((3, 3))
@@ -322,13 +352,6 @@ class TestCentroidSources:
         assert not np.allclose(xcen1, xcen2)
         assert not np.allclose(ycen1, ycen2)
 
-        # mask all data values
-        mask = np.ones(self.data.shape, dtype=bool)
-        xcen3, ycen3 = centroid_sources(self.data, 25, 23,
-                                        box_size=(55, 55), mask=mask)
-        assert np.isnan(xcen3[0])
-        assert np.isnan(ycen3[0])
-
     def test_error_none(self):
         xycen1 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
                                   centroid_func=centroid_1dg)
@@ -350,3 +373,25 @@ class TestCentroidSources:
         assert_allclose(xycen1, ([25], [25]), atol=1.0e-3)
         assert_allclose(xycen2, ([25], [25]), atol=1.0e-3)
         assert_allclose(xycen3, ([25], [25]), atol=1.0e-3)
+
+
+def test_cutout_mask():
+    """
+    Test that the cutout is not completely masked (see #1514).
+    """
+    data = make_4gaussians_image()
+    x_init = (25, 91, 151, 160)
+    y_init = (40, 61, 24, 71)
+    with pytest.raises(ValueError):
+        footprint = np.zeros((3, 3))
+        _ = centroid_sources(data, x_init, y_init, footprint=footprint,
+                             centroid_func=centroid_com)
+
+    with pytest.raises(ValueError):
+        footprint = np.zeros(data.shape, dtype=bool)
+        _ = centroid_sources(data, x_init, y_init, footprint=footprint,
+                             centroid_func=centroid_com)
+
+    with pytest.raises(ValueError):
+        mask = np.ones(data.shape, dtype=bool)
+        _ = centroid_sources(data, x_init, y_init, box_size=11, mask=mask)
