@@ -3,9 +3,6 @@
 # get picked up when running the tests inside an interpreter using
 # packagename.test
 
-import numpy as np
-from astropy.utils import minversion
-
 try:
     from pytest_astropy_header.display import (PYTEST_HEADER_MODULES,
                                                TESTED_VERSIONS)
@@ -13,10 +10,6 @@ try:
 except ImportError:
     ASTROPY_HEADER = False
 
-# do not remove until we drop support for NumPy < 2.0
-if minversion(np, '2.0.0.dev0+git20230726'):
-    np.set_printoptions(legacy='1.25')
-
 
 def pytest_configure(config):
     if ASTROPY_HEADER:
@@ -26,8 +19,8 @@ def pytest_configure(config):
         # list of packages for which version numbers are displayed when
         # running the tests.
         PYTEST_HEADER_MODULES.clear()
-        deps = ['NumPy', 'SciPy', 'Matplotlib', 'Astropy', 'scikit-image',
-                'scikit-learn', 'GWCS', 'Bottleneck', 'tqdm', 'Rasterio',
+        deps = ['NumPy', 'SciPy', 'Matplotlib', 'Astropy', 'skimage',
+                'sklearn', 'GWCS', 'Bottleneck', 'tqdm', 'Rasterio',
                 'Shapely']
         for dep in deps:
             PYTEST_HEADER_MODULES[dep] = dep.lower()
