@@ -10,33 +10,34 @@ import numpy as np
 from astropy.table import QTable
 
 from photutils.utils._misc import _get_meta
+from photutils.utils._quantity_helpers import process_quantities
 from photutils.utils.exceptions import NoDetectionsWarning
 
 __all__ = ['find_peaks']
 
 
-def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
+def find_peaks(data, threshold, *, box_size=3, footprint=None, mask=None,
                border_width=None, npeaks=np.inf, centroid_func=None,
                error=None, wcs=None):
     """
-    Find local peaks in an image that are above above a specified
-    threshold value.
+    Find local peaks in an image that are above a specified threshold
+    value.
 
-    Peaks are the maxima above the ``threshold`` within a local region.
-    The local regions are defined by either the ``box_size`` or
-    ``footprint`` parameters.  ``box_size`` defines the local region
-    around each pixel as a square box.  ``footprint`` is a boolean array
+    Peaks are the maxima above the ``threshold`` within a local
+    region. The local regions are defined by either the ``box_size``
+    or ``footprint`` parameters. ``box_size`` defines the local region
+    around each pixel as a square box. ``footprint`` is a boolean array
     where `True` values specify the region shape.
 
     If multiple pixels within a local region have identical intensities,
-    then the coordinates of all such pixels are returned.  Otherwise,
-    there will be only one peak pixel per local region.  Thus, the
+    then the coordinates of all such pixels are returned. Otherwise,
+    there will be only one peak pixel per local region. Thus, the
     defined region effectively imposes a minimum separation between
     peaks unless there are identical peaks within the region.
 
     If ``centroid_func`` is input, then it will be used to calculate a
     centroid within the defined local region centered on each detected
-    peak pixel.  In this case, the centroid will also be returned in the
+    peak pixel. In this case, the centroid will also be returned in the
     output table.
 
     Parameters
@@ -44,25 +45,27 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
     data : array_like
         The 2D array of the image.
 
-    threshold : float or array_like
+    threshold : float, scalar `~astropy.units.Quantity` or array_like
         The data value or pixel-wise data values to be used for the
-        detection threshold. A 2D ``threshold`` must have the same shape
-        as ``data``. See `~photutils.segmentation.detect_threshold` for
-        one way to create a ``threshold`` image.
+        detection threshold. If ``data`` is a `~astropy.units.Quantity`
+        array, then ``threshold`` must have the same units as ``data``.
+        A 2D ``threshold`` must have the same shape as ``data``. See
+        `~photutils.segmentation.detect_threshold` for one way to create
+        a ``threshold`` image.
 
     box_size : scalar or tuple, optional
         The size of the local region to search for peaks at every point
-        in ``data``.  If ``box_size`` is a scalar, then the region shape
-        will be ``(box_size, box_size)``.  Either ``box_size`` or
-        ``footprint`` must be defined.  If they are both defined, then
+        in ``data``. If ``box_size`` is a scalar, then the region
+        shape will be ``(box_size, box_size)``. Either ``box_size`` or
+        ``footprint`` must be defined. If they are both defined, then
         ``footprint`` overrides ``box_size``.
 
     footprint : `~numpy.ndarray` of bools, optional
-        A boolean array where `True` values describe the local footprint
-        region within which to search for peaks at every point in
-        ``data``.  ``box_size=(n, m)`` is equivalent to
-        ``footprint=np.ones((n, m))``.  Either ``box_size`` or
-        ``footprint`` must be defined.  If they are both defined, then
+        A boolean array where `True` values describe the local
+        footprint region within which to search for peaks at every
+        point in ``data``. ``box_size=(n, m)`` is equivalent to
+        ``footprint=np.ones((n, m))``. Either ``box_size`` or
+        ``footprint`` must be defined. If they are both defined, then
         ``footprint`` overrides ``box_size``.
 
     mask : array_like, bool, optional
@@ -74,7 +77,7 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
         ``data``.
 
     npeaks : int, optional
-        The maximum number of peaks to return.  When the number of
+        The maximum number of peaks to return. When the number of
         detected peaks exceeds ``npeaks``, the peaks with the highest
         peak intensities will be returned.
 
@@ -89,7 +92,9 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
     error : array_like, optional
         The 2D array of the 1-sigma errors of the input ``data``.
         ``error`` is used only if ``centroid_func`` is input (the
-        ``error`` array is passed directly to the ``centroid_func``).
+        ``error`` array is passed directly to the ``centroid_func``). If
+        ``data`` is a `~astropy.units.Quantity` array, then ``error``
+        must have the same units as ``data``.
 
     wcs : `None` or WCS object, optional
         A world coordinate system (WCS) transformation that
@@ -103,9 +108,9 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
     -------
     output : `~astropy.table.Table` or `None`
         A table containing the x and y pixel location of the peaks and
-        their values.  If ``centroid_func`` is input, then the table
-        will also contain the centroid position.  If no peaks are found
-        then `None` is returned.
+        their values. If ``centroid_func`` is input, then the table will
+        also contain the centroid position. If no peaks are found then
+        `None` is returned.
 
     Notes
     -----
@@ -118,6 +123,10 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
     """
     from scipy.ndimage import maximum_filter
 
+    arrays, unit = process_quantities((data, threshold, error),
+                                      ('data', 'threshold', 'error'))
+    data, threshold, error = arrays
+
     data = np.asanyarray(data)
 
     if np.all(data == data.flat[0]):
@@ -163,6 +172,9 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
     y_peaks, x_peaks = peak_goodmask.nonzero()
     peak_values = data[y_peaks, x_peaks]
 
+    if unit is not None:
+        peak_values <<= unit
+
     nxpeaks = len(x_peaks)
     if nxpeaks > npeaks:
         idx = np.argsort(peak_values)[::-1][:npeaks]
@@ -175,14 +187,16 @@ def find_peaks(data, threshold, box_size=3, footprint=None, mask=None,
         return None
 
     # construct the output table
-    colnames = ['x_peak', 'y_peak', 'peak_value']
-    coldata = [x_peaks, y_peaks, peak_values]
+    ids = np.arange(len(x_peaks)) + 1
+    colnames = ['id', 'x_peak', 'y_peak', 'peak_value']
+    coldata = [ids, x_peaks, y_peaks, peak_values]
     table = QTable(coldata, names=colnames)
     table.meta.update(_get_meta())  # keep table.meta type
 
     if wcs is not None:
         skycoord_peaks = wcs.pixel_to_world(x_peaks, y_peaks)
-        table.add_column(skycoord_peaks, name='skycoord_peak', index=2)
+        idx = table.colnames.index('y_peak') + 1
+        table.add_column(skycoord_peaks, name='skycoord_peak', index=idx)
 
     # perform centroiding
     if centroid_func is not None:
