@@ -4,15 +4,15 @@ Tests for the geometry module.
 """
 
 import numpy as np
-from numpy.testing import assert_allclose
 import pytest
+from numpy.testing import assert_allclose
 
-from ..geometry import EllipseGeometry
+from photutils.isophote.geometry import EllipseGeometry
 
 
-@pytest.mark.parametrize('astep, linear_growth', [(0.2, False), (20., True)])
+@pytest.mark.parametrize('astep, linear_growth', [(0.2, False), (20.0, True)])
 def test_geometry(astep, linear_growth):
-    geometry = EllipseGeometry(255., 255., 100., 0.4, np.pi / 2, astep,
+    geometry = EllipseGeometry(255.0, 255.0, 100.0, 0.4, np.pi / 2, astep,
                                linear_growth)
 
     sma1, sma2 = geometry.bounding_ellipses()
@@ -28,46 +28,46 @@ def test_geometry(astep, linear_growth):
 
 
 def test_to_polar():
-    # trivial case of a circle centered in (0.,0.)
-    geometry = EllipseGeometry(0., 0., 100., 0.0, 0., 0.2, False)
+    # trivial case of a circle centered in (0.0, 0.0)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, 0.0, 0.2, False)
 
-    r, p = geometry.to_polar(100., 0.)
-    assert_allclose(r, 100., atol=0.1)
-    assert_allclose(p, 0., atol=0.0001)
+    r, p = geometry.to_polar(100.0, 0.0)
+    assert_allclose(r, 100.0, atol=0.1)
+    assert_allclose(p, 0.0, atol=0.0001)
 
-    r, p = geometry.to_polar(0., 100.)
-    assert_allclose(r, 100., atol=0.1)
-    assert_allclose(p, np.pi / 2., atol=0.0001)
+    r, p = geometry.to_polar(0.0, 100.0)
+    assert_allclose(r, 100.0, atol=0.1)
+    assert_allclose(p, np.pi / 2.0, atol=0.0001)
 
-    # vector with length 100. at 45 deg angle
+    # vector with length 100.0 at 45 deg angle
     r, p = geometry.to_polar(70.71, 70.71)
-    assert_allclose(r, 100., atol=0.1)
-    assert_allclose(p, np.pi / 4., atol=0.0001)
+    assert_allclose(r, 100.0, atol=0.1)
+    assert_allclose(p, np.pi / 4.0, atol=0.0001)
 
     # position angle tilted 45 deg from X axis
-    geometry = EllipseGeometry(0., 0., 100., 0.0, np.pi / 4., 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, np.pi / 4.0, 0.2, False)
 
-    r, p = geometry.to_polar(100., 0.)
-    assert_allclose(r, 100., atol=0.1)
-    assert_allclose(p, np.pi * 7. / 4., atol=0.0001)
+    r, p = geometry.to_polar(100.0, 0.0)
+    assert_allclose(r, 100.0, atol=0.1)
+    assert_allclose(p, np.pi * 7.0 / 4.0, atol=0.0001)
 
-    r, p = geometry.to_polar(0., 100.)
-    assert_allclose(r, 100., atol=0.1)
-    assert_allclose(p, np.pi / 4., atol=0.0001)
+    r, p = geometry.to_polar(0.0, 100.0)
+    assert_allclose(r, 100.0, atol=0.1)
+    assert_allclose(p, np.pi / 4.0, atol=0.0001)
 
-    # vector with length 100. at 45 deg angle
+    # vector with length 100.0 at 45 deg angle
     r, p = geometry.to_polar(70.71, 70.71)
-    assert_allclose(r, 100., atol=0.1)
-    assert_allclose(p, np.pi * 2., atol=0.0001)
+    assert_allclose(r, 100.0, atol=0.1)
+    assert_allclose(p, np.pi * 2.0, atol=0.0001)
 
 
 def test_area():
     # circle with center at origin
-    geometry = EllipseGeometry(0., 0., 100., 0.0, 0., 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, 0.0, 0.2, False)
 
     # sector at 45 deg on circle
     vertex_x, vertex_y = geometry.initialize_sector_geometry(
-        45. / 180. * np.pi)
+        45.0 / 180.0 * np.pi)
     assert_allclose(vertex_x, [65.21, 79.70, 62.03, 75.81], atol=0.01)
     assert_allclose(vertex_y, [62.03, 75.81, 65.21, 79.70], atol=0.01)
 
@@ -78,46 +78,46 @@ def test_area():
 
 
 def test_area2():
-    # circle with center at 100.,100.
-    geometry = EllipseGeometry(100., 100., 100., 0.0, 0., 0.2, False)
+    # circle with center at 100.0, 100.0
+    geometry = EllipseGeometry(100.0, 100.0, 100.0, 0.0, 0.0, 0.2, False)
 
     # sector at 45 deg on circle
     vertex_x, vertex_y = geometry.initialize_sector_geometry(
-        45. / 180. * np.pi)
+        45.0 / 180.0 * np.pi)
     assert_allclose(vertex_x, [165.21, 179.70, 162.03, 175.81], atol=0.01)
     assert_allclose(vertex_y, [162.03, 175.81, 165.21, 179.70], atol=0.01)
 
     # sector at 225 deg on circle
     vertex_x, vertex_y = geometry.initialize_sector_geometry(
-        225. / 180. * np.pi)
+        225.0 / 180.0 * np.pi)
     assert_allclose(vertex_x, [34.79, 20.30, 37.97, 24.19], atol=0.01)
     assert_allclose(vertex_y, [37.97, 24.19, 34.79, 20.30], atol=0.01)
 
 
 def test_reset_sma():
-    geometry = EllipseGeometry(0., 0., 100., 0.0, 0., 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, 0.0, 0.2, False)
     sma, step = geometry.reset_sma(0.2)
     assert_allclose(sma, 83.33, atol=0.01)
     assert_allclose(step, -0.1666, atol=0.001)
 
-    geometry = EllipseGeometry(0., 0., 100., 0.0, 0., 20., True)
-    sma, step = geometry.reset_sma(20.)
-    assert_allclose(sma, 80., atol=0.01)
-    assert_allclose(step, -20., atol=0.01)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, 0.0, 20.0, True)
+    sma, step = geometry.reset_sma(20.0)
+    assert_allclose(sma, 80.0, atol=0.01)
+    assert_allclose(step, -20.0, atol=0.01)
 
 
 def test_update_sma():
-    geometry = EllipseGeometry(0., 0., 100., 0.0, 0., 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, 0.0, 0.2, False)
     sma = geometry.update_sma(0.2)
-    assert_allclose(sma, 120., atol=0.01)
+    assert_allclose(sma, 120.0, atol=0.01)
 
-    geometry = EllipseGeometry(0., 0., 100., 0.0, 0., 20., True)
-    sma = geometry.update_sma(20.)
-    assert_allclose(sma, 120., atol=0.01)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.0, 0.0, 20.0, True)
+    sma = geometry.update_sma(20.0)
+    assert_allclose(sma, 120.0, atol=0.01)
 
 
 def test_polar_angle_sector_limits():
-    geometry = EllipseGeometry(0., 0., 100., 0.3, np.pi / 4, 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.3, np.pi / 4, 0.2, False)
     geometry.initialize_sector_geometry(np.pi / 3)
     phi1, phi2 = geometry.polar_angle_sector_limits()
     assert_allclose(phi1, 1.022198, atol=0.0001)
@@ -125,13 +125,13 @@ def test_polar_angle_sector_limits():
 
 
 def test_bounding_ellipses():
-    geometry = EllipseGeometry(0., 0., 100., 0.3, np.pi / 4, 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.3, np.pi / 4, 0.2, False)
     sma1, sma2 = geometry.bounding_ellipses()
     assert_allclose((sma1, sma2), (90.0, 110.0), atol=0.01)
 
 
 def test_radius():
-    geometry = EllipseGeometry(0., 0., 100., 0.3, np.pi / 4, 0.2, False)
+    geometry = EllipseGeometry(0.0, 0.0, 100.0, 0.3, np.pi / 4, 0.2, False)
     r = geometry.radius(0.0)
     assert_allclose(r, 100.0, atol=0.01)
 
