@@ -28,11 +28,13 @@ class ProfileBase(metaclass=abc.ABCMeta):
         The ``(x, y)`` pixel coordinate of the source center.
 
     radii : 1D float `numpy.ndarray`
-        An array of radii defining the edges of the radial bins.
-        ``radii`` must be strictly increasing with a minimum value
-        greater than or equal to zero, and contain at least 2 values.
-        The radial spacing does not need to be constant. The output
-        `radius` attribute will be defined at the bin centers.
+        An array of radii defining the radial bins. ``radii``
+        must be strictly increasing with a minimum value greater
+        than or equal to zero, and contain at least 2 values.
+        The radial spacing does not need to be constant. For
+        `~photutils.profiles.RadialProfile`, the input radii are the
+        *edges* of the radial annulus bins, and the output `radius`
+        represents the bin centers.
 
     error : 2D `numpy.ndarray`, optional
         The 1-sigma errors of the input ``data``. ``error`` is assumed
@@ -50,7 +52,7 @@ class ProfileBase(metaclass=abc.ABCMeta):
         pixel grid:
 
             * ``'exact'`` (default):
-              The the exact fractional overlap of the aperture and each
+              The exact fractional overlap of the aperture and each
               pixel is calculated. The aperture weights will contain
               values between 0 and 1.
 
@@ -92,19 +94,20 @@ class ProfileBase(metaclass=abc.ABCMeta):
         self.mask = self._compute_mask(data, error, mask)
         self.method = method
         self.subpixels = subpixels
+        self.normalization_value = 1.0
 
-    def _validate_radii(self, edge_radii):
-        edge_radii = np.array(edge_radii)
-        if edge_radii.ndim != 1 or edge_radii.size < 2:
-            raise ValueError('edge_radii must be a 1D array and have at '
+    def _validate_radii(self, radii):
+        radii = np.array(radii)
+        if radii.ndim != 1 or radii.size < 2:
+            raise ValueError('radii must be a 1D array and have at '
                              'least two values')
-        if edge_radii.min() < 0:
-            raise ValueError('minimum edge_radii must be >= 0')
+        if radii.min() < 0:
+            raise ValueError('minimum radii must be >= 0')
 
-        if not np.all(edge_radii[1:] > edge_radii[:-1]):
-            raise ValueError('edge_radii must be strictly increasing')
+        if not np.all(radii[1:] > radii[:-1]):
+            raise ValueError('radii must be strictly increasing')
 
-        return edge_radii
+        return radii
 
     def _compute_mask(self, data, error, mask):
         """
@@ -134,7 +137,7 @@ class ProfileBase(metaclass=abc.ABCMeta):
         """
         The profile radius in pixels as a 1D `~numpy.ndarray`.
         """
-        return self.radii
+        raise NotImplementedError('Needs to be implemented in a subclass.')
 
     @property
     @abc.abstractmethod
@@ -213,7 +216,7 @@ class ProfileBase(metaclass=abc.ABCMeta):
             The method used to normalize the profile:
 
                 * 'max' (default):
-                  The profile is normalized such that its peak value is
+                  The profile is normalized such that its maximum value is
                   1.
                 * 'sum':
                   The profile is normalized such that its sum (integral)
@@ -224,15 +227,29 @@ class ProfileBase(metaclass=abc.ABCMeta):
         elif method == 'sum':
             normalization = np.nansum(self.profile)
         else:
-            raise ValueError('invalid method, must be "peak" or "integral"')
+            raise ValueError('invalid method, must be "max" or "sum"')
 
         if normalization == 0:
             warnings.warn('The profile cannot be normalized because the '
                           'max or sum is zero.', AstropyUserWarning)
         else:
+            # normalization_values accumulate if normalize is run
+            # multiple times (e.g., different methods)
+            self.normalization_value *= normalization
+
+            # need to use __dict__ as these are lazy properties
             self.__dict__['profile'] = self.profile / normalization
             self.__dict__['profile_error'] = self.profile_error / normalization
 
+    def unnormalize(self):
+        """
+        Unnormalize the profile back to the original state before any
+        calls to `normalize`.
+        """
+        self.__dict__['profile'] = self.profile * self.normalization_value
+        self.__dict__['profile_error'] = self.profile_error * self.normalization_value
+        self.normalization_value = 1.0
+
     def plot(self, ax=None, **kwargs):
         """
         Plot the profile.
@@ -240,7 +257,7 @@ class ProfileBase(metaclass=abc.ABCMeta):
         Parameters
         ----------
         ax : `matplotlib.axes.Axes` or `None`, optional
-            The matplotlib axes on which to plot.  If `None`, then the
+            The matplotlib axes on which to plot. If `None`, then the
             current `~matplotlib.axes.Axes` instance is used.
 
         **kwargs : `dict`
@@ -272,7 +289,7 @@ class ProfileBase(metaclass=abc.ABCMeta):
         Parameters
         ----------
         ax : `matplotlib.axes.Axes` or `None`, optional
-            The matplotlib axes on which to plot.  If `None`, then the
+            The matplotlib axes on which to plot. If `None`, then the
             current `~matplotlib.axes.Axes` instance is used.
 
         **kwargs : `dict`
