@@ -15,13 +15,13 @@ from photutils.profiles.core import ProfileBase
 
 __all__ = ['RadialProfile']
 
-__doctest_requires__ = {('RadialProfile'): ['scipy']}
+__doctest_requires__ = {'RadialProfile': ['scipy']}
 
 
 class RadialProfile(ProfileBase):
     """
     Class to create a radial profile using concentric circular
-    apertures.
+    annulus apertures.
 
     The radial profile represents the azimuthally-averaged flux in
     circular annuli apertures as a function of radius.
@@ -30,6 +30,8 @@ class RadialProfile(ProfileBase):
     bins. This differs from the `RadialProfile` class, where the inputs
     represent the centers of the radial bins.
 
+    The output `radius` attribute represents the bin centers.
+
     Parameters
     ----------
     data : 2D `numpy.ndarray`
@@ -40,9 +42,9 @@ class RadialProfile(ProfileBase):
     xycen : tuple of 2 floats
         The ``(x, y)`` pixel coordinate of the source center.
 
-    edge_radii : 1D float `numpy.ndarray`
-        An array of radii defining the edges of the radial bins.
-        ``edge_radii`` must be strictly increasing with a minimum value
+    radii : 1D float `numpy.ndarray`
+        An array of radii defining the *edges* of the radial bins.
+        ``radii`` must be strictly increasing with a minimum value
         greater than or equal to zero, and contain at least 2 values.
         The radial spacing does not need to be constant. The output
         `radius` attribute will be defined at the bin centers.
@@ -65,7 +67,7 @@ class RadialProfile(ProfileBase):
         pixel grid:
 
             * ``'exact'`` (default):
-              The the exact fractional overlap of the aperture and each
+              The exact fractional overlap of the aperture and each
               pixel is calculated. The aperture weights will contain
               values between 0 and 1.
 
@@ -95,9 +97,9 @@ class RadialProfile(ProfileBase):
 
     Notes
     -----
-    If the minimum of ``edge_radii`` is zero, then a circular aperture
-    with radius equal to ``edge_radii[1]`` will be used for the
-    innermost aperture.
+    If the minimum of ``radii`` is zero, then a circular aperture
+    with radius equal to ``radii[1]`` will be used for the innermost
+    aperture.
 
     Examples
     --------
@@ -238,6 +240,7 @@ class RadialProfile(ProfileBase):
         plt.imshow(data, norm=norm)
         rp.apertures[5].plot(color='C0', lw=2)
         rp.apertures[10].plot(color='C1', lw=2)
+        rp.apertures[15].plot(color='C3', lw=2)
 
     Fit a 1D Gaussian to the radial profile and return the Gaussian
     model.
