@@ -8,22 +8,13 @@ import warnings
 
 import numpy as np
 from astropy.modeling import Fittable2DModel, Parameter
-from astropy.utils.decorators import deprecated
-from astropy.utils.exceptions import AstropyUserWarning, AstropyWarning
+from astropy.utils.exceptions import AstropyUserWarning
 
 from photutils.aperture import CircularAperture
 from photutils.utils._parameters import as_pair
 
-__all__ = ['NonNormalizable', 'FittableImageModel', 'EPSFModel',
-           'IntegratedGaussianPRF', 'PRFAdapter']
-
-
-@deprecated('1.11.0', alternative='AstropyUserWarning')
-class NonNormalizable(AstropyWarning):
-    """
-    Used to indicate that a :py:class:`FittableImageModel` model is
-    non-normalizable.
-    """
+__all__ = ['FittableImageModel', 'EPSFModel', 'IntegratedGaussianPRF',
+           'PRFAdapter']
 
 
 class FittableImageModel(Fittable2DModel):
@@ -31,14 +22,14 @@ class FittableImageModel(Fittable2DModel):
     A fittable 2D model of an image allowing for image intensity scaling
     and image translations.
 
-    This class takes 2D image data and computes the values of the model
-    at arbitrary locations (including at intra-pixel, fractional
+    This class takes 2D image data and computes the values of the
+    model at arbitrary locations (including at intra-pixel, fractional
     positions) within this image using spline interpolation provided by
     :py:class:`~scipy.interpolate.RectBivariateSpline`.
 
     The fittable model provided by this class has three model
-    parameters: an image intensity scaling factor (``flux``) which is
-    applied to (normalized) image, and two positional parameters
+    parameters: an image intensity scaling factor (``flux``) which
+    is applied to (normalized) image, and two positional parameters
     (``x_0`` and ``y_0``) indicating the location of a feature in the
     coordinate grid on which the model is to be evaluated.
 
@@ -56,9 +47,9 @@ class FittableImageModel(Fittable2DModel):
         is `None`, origin will be set at the middle of the image array.
 
         If ``origin`` represents the location of a feature (e.g., the
-        position of an intensity peak) in the input ``data``, then model
-        parameters ``x_0`` and ``y_0`` show the location of this peak in
-        an another target image to which this model was fitted.
+        position of an intensity peak) in the input ``data``, then
+        model parameters ``x_0`` and ``y_0`` show the location of this
+        peak in an another target image to which this model was fitted.
         Fundamentally, it is the coordinate in the model's image data
         that should map to coordinate (``x_0``, ``y_0``) of the output
         coordinate system on which the model is evaluated.
@@ -83,16 +74,16 @@ class FittableImageModel(Fittable2DModel):
     normalization_correction : float, optional
         A strictly positive number that represents correction that needs
         to be applied to model's data normalization (see *C* in the
-        equation in the comments to ``normalize`` for more details).  A
-        possible application for this parameter is to account for
+        equation in the comments to ``normalize`` for more details).
+        A possible application for this parameter is to account for
         aperture correction. Assuming model's data represent a PSF to be
         fitted to some target star, we set ``normalization_correction``
         to the aperture correction that needs to be applied to the
         model. That is, ``normalization_correction`` in this case should
         be set to the ratio between the total flux of the PSF (including
-        flux outside model's data) to the flux of model's data.  Then,
+        flux outside model's data) to the flux of model's data. Then,
         best fitted value of the ``flux`` model parameter will represent
-        an aperture-corrected flux of the target star.  In the case of
+        an aperture-corrected flux of the target star. In the case of
         aperture correction, ``normalization_correction`` should be a
         value larger than one, as the total flux, including regions
         outside of the aperture, should be larger than the flux inside
@@ -106,7 +97,7 @@ class FittableImageModel(Fittable2DModel):
 
     kwargs : dict, optional
         Additional optional keyword arguments to be passed directly to
-        the `compute_interpolator` method.  See `compute_interpolator`
+        the `compute_interpolator` method. See `compute_interpolator`
         for more details.
 
     oversampling : int or array_like (int)
@@ -403,8 +394,8 @@ class FittableImageModel(Fittable2DModel):
                 Default value is degree=3.
 
             - **s** : float, optional
-                Non-negative smoothing factor. Default value s=0
-                corresponds to interpolation.  See
+                Non-negative smoothing factor. Default
+                value s=0 corresponds to interpolation. See
                 :py:class:`~scipy.interpolate.RectBivariateSpline` for
                 more details.
 
@@ -492,13 +483,13 @@ class EPSFModel(FittableImageModel):
     A class that models an effective PSF (ePSF).
 
     The EPSFModel is normalized such that the sum of the PSF over the
-    (undersampled) pixels within the the input ``norm_radius`` is 1.0.
+    (undersampled) pixels within the input ``norm_radius`` is 1.0.
     This means that when the EPSF is fit to stars, the resulting flux
     corresponds to aperture photometry within a circular aperture of
     radius ``norm_radius``.
 
     While this class is a subclass of `FittableImageModel`, it is very
-    similar.  The primary differences/motivation are a few additional
+    similar. The primary differences/motivation are a few additional
     parameters necessary specifically for ePSFs.
 
     Parameters
@@ -617,8 +608,8 @@ class EPSFModel(FittableImageModel):
                 Default value is degree=3.
 
             - **s** : float, optional
-                Non-negative smoothing factor. Default value s=0
-                corresponds to interpolation.  See
+                Non-negative smoothing factor. Default
+                value s=0 corresponds to interpolation. See
                 :py:class:`~scipy.interpolate.RectBivariateSpline` for
                 more details.
 
@@ -746,11 +737,52 @@ class IntegratedGaussianPRF(Fittable2DModel):
 
     _erf = None
 
-    @property
-    def bounding_box(self):
-        halfwidth = 4 * self.sigma
-        return ((int(self.y_0 - halfwidth), int(self.y_0 + halfwidth)),
-                (int(self.x_0 - halfwidth), int(self.x_0 + halfwidth)))
+    def bounding_box(self, factor=5.5):
+        """
+        Tuple defining the default ``bounding_box`` limits, ``(x_low,
+        x_high)``.
+
+        Parameters
+        ----------
+        factor : float
+            The multiple of `sigma` used to define the limits. The
+            default is 5.5, corresponding to a relative flux error less
+            than 5e-9.
+
+        Examples
+        --------
+        >>> from photutils.psf import IntegratedGaussianPRF
+        >>> model = IntegratedGaussianPRF(x_0=0, y_0=0, sigma=2)
+        >>> model.bounding_box
+        ModelBoundingBox(
+            intervals={
+                x: Interval(lower=-11.0, upper=11.0)
+                y: Interval(lower=-11.0, upper=11.0)
+            }
+            model=IntegratedGaussianPRF(inputs=('x', 'y'))
+            order='C'
+        )
+
+        This range can be set directly (see: `Model.bounding_box
+        <astropy.modeling.Model.bounding_box>`) or by using a different
+        factor, like:
+
+        >>> model.bounding_box = model.bounding_box(factor=2)
+        >>> model.bounding_box
+        ModelBoundingBox(
+            intervals={
+                x: Interval(lower=-4.0, upper=4.0)
+                y: Interval(lower=-4.0, upper=4.0)
+            }
+            model=IntegratedGaussianPRF(inputs=('x', 'y'))
+            order='C'
+        )
+        """
+        delta = factor * self.sigma
+        return (
+            (self.y_0 - delta, self.y_0 + delta),
+            (self.x_0 - delta, self.x_0 + delta),
+        )
 
     def __init__(self, sigma=sigma.default,
                  x_0=x_0.default, y_0=y_0.default, flux=flux.default,
@@ -775,7 +807,7 @@ class PRFAdapter(Fittable2DModel):
     """
     A model that adapts a supplied PSF model to act as a PRF.
 
-    It integrates the PSF model over pixel "boxes".  A critical built-in
+    It integrates the PSF model over pixel "boxes". A critical built-in
     assumption is that the PSF model scale and location parameters are
     in *pixel* units.
 
@@ -783,23 +815,27 @@ class PRFAdapter(Fittable2DModel):
     ----------
     psfmodel : a 2D model
         The model to assume as representative of the PSF.
+
     renormalize_psf : bool
         If True, the model will be integrated from -inf to inf and
-        re-scaled so that the total integrates to 1.  Note that this
+        re-scaled so that the total integrates to 1. Note that this
         renormalization only occurs *once*, so if the total flux of
         ``psfmodel`` depends on position, this will *not* be correct.
+
     xname : str or None
         The name of the ``psfmodel`` parameter that corresponds to the
-        x-axis center of the PSF.  If None, the model will be assumed to
+        x-axis center of the PSF. If None, the model will be assumed to
         be centered at x=0.
+
     yname : str or None
         The name of the ``psfmodel`` parameter that corresponds to the
-        y-axis center of the PSF.  If None, the model will be assumed to
+        y-axis center of the PSF. If None, the model will be assumed to
         be centered at y=0.
+
     fluxname : str or None
-        The name of the ``psfmodel`` parameter that corresponds to the
-        total flux of the star.  If None, a scaling factor will be
-        applied by the ``PRFAdapter`` instead of modifying the
+        The name of the ``psfmodel`` parameter that corresponds to
+        the total flux of the star. If None, a scaling factor will
+        be applied by the ``PRFAdapter`` instead of modifying the
         ``psfmodel``.
 
     Notes
@@ -869,7 +905,7 @@ class PRFAdapter(Fittable2DModel):
     def _integrated_psfmodel(self, dx, dy):
         from scipy.integrate import dblquad
 
-        # infer type/shape from the PSF model.  Seems wasteful, but the
+        # infer type/shape from the PSF model. Seems wasteful, but the
         # integration step is a *lot* more expensive so its just peanuts
         out = np.empty_like(self.psfmodel(dx, dy))
         outravel = out.ravel()
