@@ -68,8 +68,8 @@ def detect_threshold(data, nsigma, *, background=None, error=None, mask=None,
     Returns
     -------
     threshold : 2D `~numpy.ndarray`
-        A 2D image with the same shape as ``data`` containing the
-        pixel-wise threshold values.
+        A 2D image with the same shape (and units) as ``data``
+        containing the pixel-wise threshold values.
 
     See Also
     --------
@@ -84,9 +84,10 @@ def detect_threshold(data, nsigma, *, background=None, error=None, mask=None,
     sigma-clipped background statistics. If ``background`` and ``error``
     are both input, then ``mask`` and ``sigma_clip`` are ignored.
     """
-    arrays, unit = process_quantities((data, background, error),
-                                      ('data', 'background', 'error'))
-    data, background, error = arrays
+    inputs = (data, background, error)
+    names = ('data', 'background', 'error')
+    inputs, unit = process_quantities(inputs, names)
+    (data, background, error) = inputs
 
     if not isinstance(sigma_clip, SigmaClip):
         raise TypeError('sigma_clip must be a SigmaClip object')
@@ -126,13 +127,13 @@ def _detect_sources(data, thresholds, npixels, footprint, inverse_mask, *,
     Detect sources above a specified threshold value in an image.
 
     Detected sources must have ``npixels`` connected pixels that are
-    each greater than the ``threshold`` value.  If the filtering option
+    each greater than the ``threshold`` value. If the filtering option
     is used, then the ``threshold`` is applied to the filtered image.
     The input ``mask`` can be used to mask pixels in the input data.
     Masked pixels will not be included in any source.
 
-    This function does not deblend overlapping sources.  First use this
-    function to detect sources followed by
+    This function does not deblend overlapping sources.
+    First use this function to detect sources followed by
     :func:`~photutils.segmentation.deblend_sources` to deblend sources.
 
     Parameters
@@ -144,8 +145,9 @@ def _detect_sources(data, thresholds, npixels, footprint, inverse_mask, *,
     thresholds : list of 2D `~numpy.ndarray` or 1D array of floats
         The data values (as a 1D array of floats) or pixel-wise data
         values (as a sequence of 2D arrays) to be used for the detection
-        thresholds. 2D threshold arrays must have the same shape as
-        ``data``.
+        thresholds. If ``data`` is a `~astropy.units.Quantity` array,
+        then ``thresholds`` must have the same units as ``data``. 2D
+        threshold arrays must have the same shape as ``data``.
 
     npixels : int
         The minimum number of connected pixels, each greater than
@@ -254,13 +256,13 @@ def detect_sources(data, threshold, npixels, *, connectivity=8, mask=None):
     Detect sources above a specified threshold value in an image.
 
     Detected sources must have ``npixels`` connected pixels that are
-    each greater than the ``threshold`` value.  If the filtering option
+    each greater than the ``threshold`` value. If the filtering option
     is used, then the ``threshold`` is applied to the filtered image.
     The input ``mask`` can be used to mask pixels in the input data.
     Masked pixels will not be included in any source.
 
-    This function does not deblend overlapping sources.  First use this
-    function to detect sources followed by
+    This function does not deblend overlapping sources.
+    First use this function to detect sources followed by
     :func:`~photutils.segmentation.deblend_sources` to deblend sources.
 
     Parameters
@@ -271,8 +273,9 @@ def detect_sources(data, threshold, npixels, *, connectivity=8, mask=None):
 
     threshold : float or 2D `~numpy.ndarray`
         The data value or pixel-wise data values to be used for the
-        detection threshold. A 2D ``threshold`` array must have the same
-        shape and units as ``data``.
+        detection threshold. If ``data`` is a `~astropy.units.Quantity`
+        array, then ``threshold`` must have the same units as ``data``.
+        A 2D ``threshold`` array must have the same shape as ``data``.
 
     npixels : int
         The minimum number of connected pixels, each greater than
