@@ -833,6 +833,19 @@ class TestSourceCatalog:
         tbl = self.cat.to_table()
         assert len(tbl) == 7
 
+    def test_tiny_sources(self):
+        data = np.zeros((11, 11))
+        data[5, 5] = 1.0
+        data[8, 8] = 1.0
+        segm = detect_sources(data, 0.1, 1)
+        data[8, 8] = 0
+        cat = SourceCatalog(data, segm)
+        assert_allclose(cat[0].covariance,
+                        [(1 / 12, 0), (0, 1 / 12)] * u.pix**2)
+        assert_allclose(cat[1].covariance,
+                        [(np.nan, np.nan), (np.nan, np.nan)] * u.pix**2)
+        assert_allclose(cat.fwhm, [0.67977799, np.nan] * u.pix)
+
 
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.skipif(not HAS_SKIMAGE, reason='skimage is required')
@@ -857,35 +870,35 @@ def test_kron_params():
     cat = SourceCatalog(data, segm, convolved_data=convolved_data,
                         kron_params=kron_params)
     assert cat.kron_radius.value.min() == minrad
-    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    assert_allclose(cat.kron_flux.min(), 264.775307)
     rh = cat.fluxfrac_radius(0.5)
-    assert_allclose(rh.value.min(), 1.3925520107605818)
+    assert_allclose(rh.value.min(), 1.293722, rtol=1e-6)
 
     minrad = 1.2
     kron_params = (2.5, minrad, 0.0)
     cat = SourceCatalog(data, segm, convolved_data=convolved_data,
                         kron_params=kron_params)
     assert cat.kron_radius.value.min() == minrad
-    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    assert_allclose(cat.kron_flux.min(), 264.775307)
     rh = cat.fluxfrac_radius(0.5)
-    assert_allclose(rh.value.min(), 1.3979610808075127)
+    assert_allclose(rh.value.min(), 1.312618, rtol=1e-6)
 
     minrad = 0.2
     kron_params = (2.5, minrad, 0.0)
     cat = SourceCatalog(data, segm, convolved_data=convolved_data,
                         kron_params=kron_params)
-    assert_allclose(cat.kron_radius.value.min(), 0.5712931578847312)
-    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    assert_allclose(cat.kron_radius.value.min(), 0.677399, rtol=1e-6)
+    assert_allclose(cat.kron_flux.min(), 264.775307)
     rh = cat.fluxfrac_radius(0.5)
-    assert_allclose(rh.value.min(), 1.34218684691197)
+    assert_allclose(rh.value.min(), 1.232554)
 
     kron_params = (2.5, 1.4, 7.0)
     cat = SourceCatalog(data, segm, convolved_data=convolved_data,
                         kron_params=kron_params)
     assert cat.kron_radius.value.min() == 0.0
-    assert_allclose(cat.kron_flux.min(), 246.91339096556538)
+    assert_allclose(cat.kron_flux.min(), 264.775307)
     rh = cat.fluxfrac_radius(0.5)
-    assert_allclose(rh.value.min(), 1.3649418211298536)
+    assert_allclose(rh.value.min(), 1.288211, rtol=1e-6)
     assert isinstance(cat.kron_aperture[0], CircularAperture)
 
 
