@@ -16,6 +16,7 @@ from photutils.utils._repr import make_repr
 from photutils.utils.footprints import circular_footprint
 
 __all__ = ['ImageDepth']
+
 __doctest_requires__ = {('ImageDepth', 'ImageDepth.*'): ['scipy', 'skimage']}
 
 
@@ -141,11 +142,11 @@ class ImageDepth:
     >>> mask = segment_map.make_source_mask()
     >>> radius = 4
     >>> depth = ImageDepth(radius, nsigma=5.0, napers=500, niters=2,
-    ...                    overlap=False, seed=123, zeropoint=23.9,
-    ...                    progress_bar=False)
+    ...                    mask_pad=5, overlap=False, seed=123,
+    ...                    zeropoint=23.9, progress_bar=False)
     >>> limits = depth(data, mask)
-    >>> print(limits)  # doctest: +FLOAT_CMP
-    (68.0112578151062, 19.318547982855563)
+    >>> print(np.array(limits))  # doctest: +FLOAT_CMP
+    [68.7403149  19.30697121]
 
     .. plot::
         :include-source:
@@ -187,15 +188,15 @@ class ImageDepth:
                             wspace=0.15)
     """
 
-    def __init__(self, aper_radius, *, nsigma=5.0, mask_pad=5, napers=1000,
+    def __init__(self, aper_radius, *, nsigma=5.0, mask_pad=0, napers=1000,
                  niters=10, overlap=True, overlap_maxiters=100, seed=None,
                  zeropoint=0.0, sigma_clip=SigmaClip(sigma=3.0, maxiters=10),
                  progress_bar=True):
 
         if aper_radius <= 0:
             raise ValueError('aper_radius must be > 0')
-        if mask_pad <= 0:
-            raise ValueError('mask_pad must be > 0')
+        if mask_pad < 0:
+            raise ValueError('mask_pad must be >= 0')
 
         self.aper_radius = aper_radius
         self.nsigma = nsigma
