@@ -7,7 +7,7 @@ import numpy as np
 
 __all__ = ['ShepardIDWInterpolator']
 
-__doctest_requires__ = {('ShepardIDWInterpolator'): ['scipy']}
+__doctest_requires__ = {'ShepardIDWInterpolator': ['scipy']}
 
 
 class ShepardIDWInterpolator:
@@ -55,7 +55,7 @@ class ShepardIDWInterpolator:
 
     leafsize : float, optional
         The number of points at which the k-d tree algorithm switches
-        over to brute-force. ``leafsize`` must be positive.  See
+        over to brute-force. ``leafsize`` must be positive. See
         `scipy.spatial.cKDTree` for further information.
 
     Notes
@@ -77,7 +77,7 @@ class ShepardIDWInterpolator:
 
     Examples
     --------
-    This class can can be instantiated using the following syntax::
+    This class can be instantiated using the following syntax::
 
         >>> from photutils.utils import ShepardIDWInterpolator as idw
 
@@ -88,9 +88,9 @@ class ShepardIDWInterpolator:
         >>> x = rng.random(100)  # 100 random values
         >>> y = np.sin(x)
         >>> f = idw(x, y)
-        >>> f(0.4)  # doctest: +FLOAT_CMP
+        >>> float(f(0.4))  # doctest: +FLOAT_CMP
         0.38937843420912366
-        >>> np.sin(0.4)  # doctest: +FLOAT_CMP
+        >>> float(np.sin(0.4))  # doctest: +FLOAT_CMP
         0.3894183423086505
 
         >>> xi = rng.random(4)  # 4 random values
@@ -110,9 +110,9 @@ class ShepardIDWInterpolator:
         >>> pos = rng.random((1000, 2))
         >>> val = np.sin(pos[:, 0] + pos[:, 1])
         >>> f = idw(pos, val)
-        >>> f([0.5, 0.6])  # doctest: +FLOAT_CMP
+        >>> float(f([0.5, 0.6]))  # doctest: +FLOAT_CMP
         0.8948257014687874
-        >>> np.sin(0.5 + 0.6)  # doctest: +FLOAT_CMP
+        >>> float(np.sin(0.5 + 0.6))  # doctest: +FLOAT_CMP
         0.8912073600614354
     """
 
@@ -195,7 +195,7 @@ class ShepardIDWInterpolator:
 
         power : float, optional
             The power of the inverse distance used for the interpolation
-            weights.  See the Notes section for more details.
+            weights. See the Notes section for more details.
 
         reg : float, optional
             The regularization parameter. It may be used to control the
