@@ -8,7 +8,7 @@ import numpy as np
 import pytest
 from numpy.testing import assert_equal
 
-from photutils.utils._quantity_helpers import process_quantities
+from photutils.utils._quantity_helpers import isscalar, process_quantities
 
 
 @pytest.mark.parametrize('all_units', (False, True))
@@ -31,24 +31,39 @@ def test_units(all_units):
 
 
 def test_mixed_units():
+    match = 'must all have the same units'
     arrs = (np.ones(3) * u.Jy, np.ones(3) * u.km)
     names = ('a', 'b')
-    with pytest.raises(ValueError):
+
+    with pytest.raises(ValueError, match=match):
         _, _ = process_quantities(arrs, names)
 
     arrs = (np.ones(3) * u.Jy, np.ones(3))
     names = ('a', 'b')
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=match):
         _, _ = process_quantities(arrs, names)
 
     unit = u.Jy
     arrs = (np.ones(3) * unit, np.ones(3), np.ones(3) * unit)
     names = ('a', 'b', 'c')
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=match):
         _, _ = process_quantities(arrs, names)
 
     unit = u.Jy
     arrs = (np.ones(3) * unit, np.ones(3), np.ones(3) * u.km)
     names = ('a', 'b', 'c')
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=match):
         _, _ = process_quantities(arrs, names)
+
+
+def test_inputs():
+    match = 'The number of values must match the number of names'
+    with pytest.raises(ValueError, match=match):
+        _, _ = process_quantities([1, 2, 3], ['a', 'b'])
+
+
+def test_isscalar():
+    assert isscalar(1)
+    assert isscalar(1.0 * u.m)
+    assert not isscalar([1, 2, 3])
+    assert not isscalar([1, 2, 3] * u.m)
